@@ -1,8 +1,49 @@
 # -*- coding: utf-8 -*-
+import inspect
 import json
 from multiprocessing import RLock
+import os
+import sys
 import threading
 import time
+import traceback
+from loguru import logger
+
+#  时间输出格式为：2020-01-01 00:00:00
+logid = logger.add("run.log", 
+           rotation="7 days",
+           retention="30 days",
+           format="{time:YYYY-MM-DD HH:mm:ss} {level} {message}",
+           colorize=False,
+           enqueue=True,
+           catch=True,
+           level="DEBUG")
+
+# 添加错误日志输出到error.log
+logger.add("error.log", 
+        rotation="7 days",
+        retention="30 days",
+        format="{time:YYYY-MM-DD HH:mm:ss} {level} {message}",
+        colorize=False,
+        enqueue=True,
+        catch=True,
+        level="ERROR")
+
+
+def set_log_level(level):
+    global logid
+    logger.remove(logid)
+    # 配置终端输出按照level级别过滤后输出
+    my_filter = lambda record: record["level"].name == level
+    logid = logger.add("run.log", 
+           rotation="7 days",
+           retention="30 days",
+           format="{time:YYYY-MM-DD HH:mm:ss} {level} {message}",
+           colorize=False,
+           enqueue=True,
+           catch=True,
+           level="DEBUG",
+           filter=my_filter)
 
 import paho.mqtt.client as mqtt
 
@@ -332,3 +373,32 @@ class Dxr_UnSubscriber:
         self.topic = topic
         mqttc.unsubscribe(self.topic)
         callback_dit.pop(self.topic)
+
+# 定义一个猴子补丁，用来替换原来的print函数
+def monky_print(*args, **kwargs):
+    # 获取所在文件名和行号
+    file_name = inspect.stack()[1].filename
+    # 只取文件名
+    file_name = os.path.basename(file_name)
+    line = inspect.stack()[1].lineno
+    # 获取当前的线程名
+    thread_name = threading.current_thread().name
+    # 获取当前线程数量
+    thread_count = threading.active_count()
+    isException = False
+    # 判断*args是否是错误类型
+    for arg in args:
+        if isinstance(arg, Exception):
+            isException = True
+            break
+    if isException:
+        logger.exception(f'{file_name}:{line} {thread_name} {thread_count} {args}')
+    else:
+        # 将args转换为字符串
+        args = [str(arg) for arg in args]
+        # 将字符串拼接起来
+        args = " ".join(args)
+        logger.info(f'thread_name:{thread_name} thread_count:{thread_count} {file_name}:{line} {args}')
+    
+        
+# print = monky_print
\ No newline at end of file
